@@ -5,5 +5,5 @@
 #' n_narm(1:100, c(NA, 1:99))
 #' @export
 n_narm <- function(...){
-    sum(complete.cases(...))
+    sum(stats::complete.cases(...))
   }
